<?php

namespace Drupal\rabbit_hole_href\Plugin\RabbitHoleBehaviorPlugin;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\rabbit_hole\Plugin\RabbitHoleBehaviorPlugin\PageRedirect;
use Drupal\rabbit_hole_href\Plugin\RabbitHoleActionTargetBehaviorPluginInterface;
use Drupal\Core\Config\ImmutableConfig;

/**
 * Redirects to another page (see PageRedirect) and provides the
 * action target to allow rewriting of links pointing to the handled entity.
 *
 * @RabbitHoleBehaviorPlugin(
 *   id = "page_redirect_href",
 *   label = @Translation("Page redirect with automatic link rewriting to the redirect target."),
 *   description = @Translation("Redirects direct access to the entity to the configured destination and rewrites links pointing to this entity directly to the redirect target URL.")
 * )
 */
class PageRedirectHref extends PageRedirect implements ContainerFactoryPluginInterface, RabbitHoleActionTargetBehaviorPluginInterface
{

  /**
   * {@inheritdoc}
   */
  public function settingsForm(&$form, &$form_state, $form_id, EntityInterface $entity = NULL, $entity_is_bundle = FALSE, ImmutableConfig $bundle_settings = NULL)
  {
    // We use the parent form for defaults
    parent::settingsForm(
      $form,
      $form_state,
      $form_id,
      $entity,
      $entity_is_bundle,
      $bundle_settings
    );

    // Required changes to the form:

    // Add this and the parent plugin as states, otherwise the redirect settings
    // form would only be visible for this item.
    $form['rabbit_hole']['redirect']['#states']['visible'][':input[name="rh_action"]'] =
      array(
        ['value' => $this->getPluginId()],
        ['value' => 'page_redirect']
      );
  }
}
